pub(crate) enum MediaElementWeakRef {
Audio(WeakRef<HTMLAudioElement>),
Video(WeakRef<HTMLVideoElement>),
}Expand description
A weak reference to an HTMLMediaElement, remembering the concrete type of
the referenced element.
A WeakRef<HTMLMediaElement> would only remember the parent type, which is not
the type an audio or video element is allocated as.
Variants
Audio(WeakRef<HTMLAudioElement>)
Video(WeakRef<HTMLVideoElement>)
Implementations
Sourceimpl MediaElementWeakRef
impl MediaElementWeakRef
Sourcepub(crate) fn new(element: &HTMLMediaElement) -> Self
pub(crate) fn new(element: &HTMLMediaElement) -> Self
Create a weak reference to the given media element.
Sourcepub(crate) fn root(&self) -> Option<DomRoot<HTMLMediaElement>>
pub(crate) fn root(&self) -> Option<DomRoot<HTMLMediaElement>>
Root the referenced element, if it has not been collected yet.