enum PlaybackPositionWasMoved {
ExplicitMove,
NormalPlayback,
}Expand description
Used to determine whether the current playback position was changed during normal playback or not in https://html.spec.whatwg.org/multipage/#time-marches-on
Variants